Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Middleware ¶
type Middleware struct {
ErrorHandler func(rw http.ResponseWriter, req *http.Request, err error)
// contains filtered or unexported fields
}
Middleware allows us to wrap http.Handler to be retried this is useful for building robust proxies
func NewMiddleware ¶
NewMiddleware
func (*Middleware) ServeHTTP ¶
func (m *Middleware) ServeHTTP(rw http.ResponseWriter, req *http.Request)
type Play ¶
type Play struct {
Bytes int
Writes int
Status int
Time time.Duration
// contains filtered or unexported fields
}
Represents one request try
type Replayer ¶
type Replayer struct {
Errors chan error
// Current play record
Play Play
// contains filtered or unexported fields
}
Replayer provides us with a mechanism to replay HTTP requests
func NewReplayer ¶
func (*Replayer) Stop ¶
func (r *Replayer) Stop()
Reset the Replayer's state so it's ready to be replayed
func (*Replayer) WriteHeader ¶
Click to show internal directories.
Click to hide internal directories.